#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-test-utils
version:              2.3.0.0
visibility:           public
id:                   hls-test-utils-2.3.0.0-IciWjmAY78V3LsoxvdTkg4
key:                  hls-test-utils-2.3.0.0-IciWjmAY78V3LsoxvdTkg4
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Utilities used in the tests of Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  ff100b906383cdb334433a6857a7fe27
exposed:              True
exposed-modules:      Test.Hls Test.Hls.FileSystem Test.Hls.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-test-utils
hs-libraries:         HShls-test-utils-2.3.0.0-IciWjmAY78V3LsoxvdTkg4
depends:
    aeson-2.2.2.0-4XfhhWkmpwnB2gRUwfJP7g
    async-2.2.6-KNp1RIrM7Vj10YlQJqjVD7 base-4.18.2.1
    blaze-markup-0.8.3.0-GrHsU7xMMxgC6OOcwg2IdQ bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    directory-1.3.8.5 extra-1.7.16-H98LN7RYlKwJ5W6Qh2fTke
    filepath-1.4.300.1 ghcide-2.3.0.0-B1hYapL86pR4o9F5tUsmKQ
    hls-graph-2.3.0.0-HeyFkA5V638Gg24w1hlpaN
    hls-plugin-api-2.3.0.0-GROrD89xiv19memSRvxoG6
    lens-5.3.5-AYBI3DxVlEzIh1R399daMf
    lsp-2.2.0.0-6qQP2gkL6rf79FYuMnhEm0
    lsp-test-0.16.0.0-5SrKzPV5nuPCSy510G1qwF
    lsp-types-2.0.2.0-Hjm9ElnjsL6F8974kvB8CT
    row-types-1.0.1.2-17dnAW4BcyR4ZB2fxcPAF3
    tasty-1.5.3-7W3ODf0SeIu7bHDUebRuXp
    tasty-expected-failure-0.12.3-7QmKBujxd1pBiLGter2d2d
    tasty-golden-2.3.6-FCeDsZlnLdd9F9rOAsHnV3
    tasty-hunit-0.10.2-9O1or8axsuhCgyb7moOYp3
    tasty-rerun-1.1.20-15gosiwbTwtFt6F5dAJcfv
    temporary-1.3-Klgi73SzFBU6HdICepglv2 text-2.0.2
    unordered-containers-0.2.20.1-3DXXOqLpcMZGFktSBwG2cs

haddock-interfaces:
    /usr/share/doc/haskell-hls-test-utils/html/hls-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-hls-test-utils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

